@@ -3,11 +3,12 @@ import numpy as np
 import re
 from collections import OrderedDict
 from .cell import cell_to_low_triangle
+from ..unit import EnergyConversion, LengthConversion, ForceConversion, PressureConversion
 
 #%%
-AU_TO_ANG = 5.29177208590000E-01
-AU_TO_EV = 2.72113838565563E+01
-AU_TO_EV_EVERY_ANG = AU_TO_EV/AU_TO_ANG
+AU_TO_ANG = LengthConversion("bohr", "angstrom").value()
+AU_TO_EV = EnergyConversion("hartree", "eV").value()
+AU_TO_EV_EVERY_ANG = ForceConversion("hartree/bohr", "eV/angstrom").value()
 delimiter_patterns=[]
 delimiter_p1 = re.compile(r'^ \* GO CP2K GO! \*+')
 delimiter_p2 = re.compile(r'^ \*+')
@@ -221,10 +222,9 @@ def get_frames (fname) :
     coord_flag = False
     force_flag = False
     stress_flag = False
-    eV = 2.72113838565563E+01 # hatree to eV
-    angstrom = 5.29177208590000E-01 # Bohr to Angstrom
-    GPa = 160.21766208 # 1 eV/(Angstrom^3) = 160.21 GPa
-    fp = open(fname)
+    eV = EnergyConversion("hartree", "eV").value()
+    angstrom = LengthConversion("bohr", "angstrom").value()
+    GPa = PressureConversion("eV/angstrom^3", "GPa").value()
     atom_symbol_list = []
     cell = []
     coord = []
@@ -232,6 +232,15 @@ def get_frames (fname) :
     stress = []
     cell_count = 0
     coord_count = 0
+
+    fp = open(fname)
+    # check if output is converged, if not, return sys = 0
+    content = fp.read()
+    count = content.count('SCF run converged')
+    if count == 0:
+        return [], [], [], [], [], [], [], []
+
+    fp.seek(0)
     for idx, ii in enumerate(fp) :
         if ('CELL| Vector' in ii) and (cell_count < 3) :
             cell.append(ii.split()[4:7])
@@ -278,20 +287,20 @@ def get_frames (fname) :
 
     #conver to float array and add extra dimension for nframes
     cell = np.array(cell)
-    cell = cell.astype(np.float)
+    cell = cell.astype(float)
     cell = cell[np.newaxis, :, :]
     coord = np.array(coord)
-    coord = coord.astype(np.float)
+    coord = coord.astype(float)
     coord = coord[np.newaxis, :, :]
     atom_symbol_list = np.array(atom_symbol_list)
     force = np.array(force)
-    force = force.astype(np.float)
+    force = force.astype(float)
     force = force[np.newaxis, :, :]
 
     # virial is not necessary
     if stress:
         stress = np.array(stress)
-        stress = stress.astype(np.float)
+        stress = stress.astype(float)
         stress = stress[np.newaxis, :, :]
         # stress to virial conversion, default unit in cp2k is GPa
         # note the stress is virial = stress * volume
